# Copyright Contributors to the fusa-gcc-plugin project
#
# SPDX-License-Identifier: LGPL-2.1-or-later

import os
import subprocess
from pathlib import Path

def get_version():
    # This function allows keeping project version aligned with the parent project. It:
    # Searches for the parent project version
    # If found - use it, and write it to a file named VERSION
    # If not found - get version from file VERSION.
    # If file VERSION not found - roll back to default version. If this happens - something went wrong
    version = "0.0.0"
    version_script_path = os.path.abspath(
        os.path.join(os.path.dirname(__file__), "../../build/version.sh"))
    version_script = Path(version_script_path)
    version_file_dir_path = os.path.abspath(os.path.dirname(__file__))
    version_file = Path(os.path.join(version_file_dir_path, "VERSION"))
    if version_script.is_file():
        version = subprocess.check_output([version_script_path, "short"], text=True).strip()
        file = open(version_file, "w")
        file.write(version)
    elif version_file.is_file():
        file = open(version_file, "r")
        version = file.read()
    else:
        print("ERROR: couldn't acquire package version, something probably went wrong")
    return version

__version__ = get_version()

if __name__ == "__main__":
    print(__version__)
